Module blaxel.core.sandbox.client.models.post_network_process_pid_monitor_response_200
======================================================================================

Classes
-------

`PostNetworkProcessPidMonitorResponse200()`
:   Method generated by attrs for class PostNetworkProcessPidMonitorResponse200.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :